/*
Author: Max Spivey, Randolph-Macon College
Last Edit: 4/13/21
This program enables cars designed for rats to drive left, right, and straight in a collaboration project between Randolph-Macon College and University of Richmond. The code works as is and if the speed needs to adjusted scroll down to line 37 where the speeds for the motors are initialized.
*/

#include <Wire.h>
#include <Adafruit_MotorShield.h>
// Create the motor shield object with the default I2C address
Adafruit_MotorShield AFMS = Adafruit_MotorShield(); 

// Initialize the motor ports
Adafruit_DCMotor *motor1 = AFMS.getMotor(1);
Adafruit_DCMotor *motor2 = AFMS.getMotor(2);
Adafruit_DCMotor *motor3 = AFMS.getMotor(3);
Adafruit_DCMotor *motor4 = AFMS.getMotor(4);
//A pin to keep track of which switch the driver has activated
int activePin = 0;

void setup() {
  //Set up pin for left turn
  pinMode(1, INPUT);
  //INPUT_PULLUP activates resistors on the board
  digitalWrite(1, INPUT_PULLUP);
  //Set up pin for drive forward
  pinMode(2, INPUT);
  digitalWrite(2, INPUT_PULLUP);
  //Set up pin for right turn
  pinMode(3, INPUT);
  digitalWrite(3, INPUT_PULLUP);

  
  //Starts the Adafruit Motor Shield
  AFMS.begin();  // create with the default frequency 1.6KHz
  
  // Set the speed to start, from 0 (off) to 255 (max speed)
  motor1->setSpeed(150);
  motor2->setSpeed(150);
  motor3->setSpeed(150);
  motor4->setSpeed(150);
  motor1->run(FORWARD);
  motor2->run(FORWARD);
  motor3->run(FORWARD);
  motor4->run(FORWARD);
  // turn on the motors
  motor1->run(RELEASE);
  motor2->run(RELEASE);
  motor3->run(RELEASE);
  motor4->run(RELEASE);
}

void loop() {
  //if turn left switch activated
  if (digitalRead(1) == HIGH)
  {
    activePin = 1;
  }
  //if drive forward switch activated
  else if (digitalRead(2) == HIGH)
  {
    activePin = 2;
  }
  //if turn right switch activated
  else if ( digitalRead(3) == HIGH)
  {
    activePin = 3;
  }

  switch (activePin) {
    case 1:
      //turn left
      motor1->run(FORWARD);
      motor2->run(BACKWARD);
      motor3->run(FORWARD);
      motor4->run(BACKWARD);
      break;
    case 2:
      //drive forward
      motor1->run(FORWARD);
      motor2->run(FORWARD);
      motor3->run(FORWARD);
      motor4->run(FORWARD);
      break;
    case 3:
      //turn right
      motor1->run(BACKWARD);
      motor2->run(FORWARD);
      motor3->run(BACKWARD);
      motor4->run(FORWARD);
      break;
    default:
      //stop motors if no switch is activated
      motor1->setSpeed(0);
      motor2->setSpeed(0);
      motor3->setSpeed(0);
      motor4->setSpeed(0);
      break;
  }
 }